"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureIsolatedDomainUrl = void 0;
var domainRegex = new RegExp('^https://[^/]*/');
/**
 * Creates an absolute url with the isolatedDomain parameter.
 * @param isolatedDomain - a domain without the protocol. Ex: "PrepSPO-appFEEAB5CE1CB0421FB1AAE5D09E0A8AAA.spgrid.com"
 * @param absoluteUrl - url with protocol that may or may not contain a path. Ex: "https://prepspo.spgrid.com"
 *
 * @internal
 */
function ensureIsolatedDomainUrl(isolatedDomain, absoluteUrl) {
    if (!isolatedDomain) {
        return absoluteUrl;
    }
    // replace the domain in "https://domain/path" with isolatedDomain
    var slashAdded = false;
    if (absoluteUrl.charAt(absoluteUrl.length - 1) !== '/') {
        absoluteUrl = absoluteUrl + '/';
        slashAdded = true;
    }
    absoluteUrl = absoluteUrl.replace(domainRegex, "https://".concat(isolatedDomain, "/"));
    if (slashAdded) {
        // Remove the ending slash
        absoluteUrl = absoluteUrl.substr(0, absoluteUrl.length - 1);
    }
    return absoluteUrl;
}
exports.ensureIsolatedDomainUrl = ensureIsolatedDomainUrl;
//# sourceMappingURL=EnsureIsolatedDomainUrl.js.map